/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.wicket.arquillian.testing;

import org.apache.wicket.arquillian.testing.util.ResourceWebApplicationPath;

/**
 * Just extends the Application to add some needs.
 * 
 * @author felipecalmeida
 * @since 06/20/2015
 */
public class TestWicketJavaEEApplication extends WicketJavaEEApplication
{

	// Has some security ignores during the test (example: accept all roles).

	@Override
	protected void initResourceFinder()
	{
		getResourceSettings().getResourceFinders().add(new ResourceWebApplicationPath(
			TestWicketJavaEEApplication.class.getPackage().getName(), getServletContext()));
	}
}
